#
# spec file for package sord
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 0

Name:           sord
Version:        0.12.2
Release:        3.4
Summary:        Utilities to work with RDF data
License:        ISC
Group:          Productivity/File utilities
Url:            http://drobilla.net/software/sord/
Source0:        http://download.drobilla.net/sord-%{version}.tar.bz2
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  pkg-config
BuildRequires:  python-base
BuildRequires:  pkgconfig(serd-0) >= 0.14.0

%description
Utilities to work with RDF data.

%package        -n libsord-0-%{soname}
Summary:        A lightweight C library for storing RDF data in memory
Group:          System/Libraries

%description    -n libsord-0-%{soname}
A lightweight C library for storing RDF data in memory.

%package        -n libsord-0-devel
Summary:        Development files for libsord
Group:          Development/Libraries/C and C++
Requires:       libsord-0-%{soname} = %{version}
Suggests:       libsord-docs

%description    -n libsord-0-devel
Development files for libsord.

# Upstream does not want versioned documentation
%package        -n libsord-docs
Summary:        Documentation about the libsord API
Group:          Documentation/Other

%description    -n libsord-docs
Documentation about the libsord API.

%prep
%setup -q

%build
export CFLAGS='%{optflags}'
export CXXFLAGS='%{optflags}'
./waf configure \
  --prefix=%{_prefix} \
  --libdir=%{_libdir} \
  --docdir=%{_defaultdocdir} \
  --docs
# waf only understands -j, so do not use smp_mflags
./waf build -v %{?jobs:-j%jobs}

%install
./waf install --destdir=%{?buildroot}

# http://dev.drobilla.net/ticket/852
cp -p doc/sord_validate.1 %{buildroot}%{_mandir}/man1/sord_validate.1

%post -n libsord-0-%{soname} -p /sbin/ldconfig

%postun -n libsord-0-%{soname} -p /sbin/ldconfig

%files
%defattr(0644,root,root,0755)
%attr(0755,-,-) %{_bindir}/sordi
%attr(0755,-,-) %{_bindir}/sord_validate
%{_mandir}/man1/sordi.1*
%{_mandir}/man1/sord_validate.1*

%files -n libsord-0-%{soname}
%defattr(0644,root,root,0755)
%doc AUTHORS COPYING NEWS README
%{_libdir}/libsord-0.so.%{soname}*

%files -n libsord-0-devel
%defattr(0644,root,root,0755)
%{_libdir}/libsord-0.so
%{_includedir}/sord-0/
%{_libdir}/pkgconfig/sord-0.pc

%files -n libsord-docs
%defattr(0644,root,root,0755)
%{_defaultdocdir}/sord-0/
%{_mandir}/man3/*

%changelog
* Wed Mar 25 2015 p.drouand@gmail.com
- Update to version 0.12.2
  * Fix iteration over an entire graph (* * * graph)
  * sordmm.hpp: Remove unused members
  * Update to waf 1.7.16
* Thu Sep  5 2013 reddwarf@opensuse.org
- Update to 0.12.0
  * Update to waf 1.7.9 and autowaf r90 (install docs to versioned directory)
  * Add sord_get() for easily getting single property values
  * sord_validate: Pass type check when range is xsd:anyURI and value is a URI
  * sord_validate: Support any subClassOf rdf:Property, not just baked-in ones
  * sordmm.hpp: Add convenient constructors for decimal and integer literals
  * sordmm.hpp: Add Node::to_serd_node()
  * sordmm.hpp: Don't automatically add RDF namespace prefix to world
* Tue Oct 23 2012 reddwarf@opensuse.org
- Remove sord-0.8.0-no_g++.patch, applied upstream
- Update to 0.10.4
  * Implement better data type validation in sord_validate conformant with
    the XSD and OWL specifications
  * Fix memory leaks in sord_validate
  * Install sord_validate man page
  * Disable timestamps in HTML documentation for reproducible build
  * Add error callback to world for custom error reporting
  * Performance and space (per node) improvements
  * SSE4.2 accelerated hashing for node interning, where available
  * Make all 'zix' symbols private to avoid symbol clashes in static builds
  * Remove problematic "Loaded n statements" output from serdi
  * Strip down API documentation to a single clean page
  * Fix various hyper-strict warnings
  * Do not require a C++ compiler to build
  * Add option to build utilities as static binaries
  * Upgrade to waf 1.7.2
  * sordmm.hpp: Add indices and graphs parameters to Model constructor
  * sordmm.hpp: Remove overzealous URI scheme assertion
  * sordmm.hpp: Correctly handle Sord::Node self-assignment
* Thu Aug 16 2012 reddwarf@opensuse.org
- Fix main package metadata
- Install sord_validate man page
- Created a libsord-docs subpackage to let multiple devel packages
  with different APIs to be installed at the same time
* Wed Aug  8 2012 reddwarf@opensuse.org
- First version of the package
- Added sord-0.8.0-no_g++.patch
